@@ -349,7 +349,7 @@ class MDG(Tk):
             main_db_path = os.path.dirname(main_db_path)
 
         self.__pointer = pointer
-        self.__local_dir = local_dir
+        self.__local_dir = local_db_dir
         self.__main_db_path = StringVar()
         self.__main_db_dir = StringVar()
         self.__local_db_path = StringVar()
@@ -373,7 +373,7 @@ class MDG(Tk):
         header2 = ['Welcome to existing database setup!', 'Please fill out the below fields to setup']
 
         # Set GUI Geometry and GUI Title
-        self.geometry('280x215+550+150')
+        self.geometry('280x195+550+150')
         self.title('Main Database Setup')
         self.resizable(False, False)
 
@@ -409,22 +409,22 @@ class MDG(Tk):
         # Apply Widgets to new_settings_frame
         #    Apply Settings Directory Entry Box Widget
         settings_dir_label = Label(new_settings_frame, text='Main DB Dir:')
-        settings_dir_entry = Entry(new_settings_frame, textvariable=self.__main_db_dir)
+        settings_dir_entry = Entry(new_settings_frame, textvariable=self.__main_db_dir, width=23)
         settings_dir_label.grid(row=0, column=0, padx=4, pady=5)
         settings_dir_entry.grid(row=0, column=1, padx=4, pady=5)
 
         #   Apply Settings Directory Finder Button Widget
-        find_settings_dir_button = Button(new_settings_frame, text='...', width=8, command=self.__main_dir_gui)
+        find_settings_dir_button = Button(new_settings_frame, text='...', width=3, command=self.__main_dir_gui)
         find_settings_dir_button.grid(row=0, column=2, padx=4, pady=5)
 
         #    Apply Settings Directory Entry Box Widget
         settings_dir_label = Label(new_settings_frame, text='Local DB Dir:')
-        settings_dir_entry = Entry(new_settings_frame, textvariable=self.__local_db_dir)
+        settings_dir_entry = Entry(new_settings_frame, textvariable=self.__local_db_dir, width=23)
         settings_dir_label.grid(row=1, column=0, padx=4, pady=5)
         settings_dir_entry.grid(row=1, column=1, padx=4, pady=5)
 
         #   Apply Settings Directory Finder Button Widget
-        find_settings_dir_button = Button(new_settings_frame, text='...', width=8, command=self.__local_dir_gui)
+        find_settings_dir_button = Button(new_settings_frame, text='...', width=3, command=self.__local_dir_gui)
         find_settings_dir_button.grid(row=1, column=2, padx=4, pady=5)
 
         # Apply Buttons to the new_buttons_frame
@@ -439,7 +439,7 @@ class MDG(Tk):
         # Apply Widgets to existing_frame
         #   Apply Main Filepath Entry Box Widget
         settings_fp_label = Label(existing_main_frame, text='Main DB Fp:')
-        settings_fp_entry = Entry(existing_main_frame, textvariable=self.__main_db_path)
+        settings_fp_entry = Entry(existing_main_frame, textvariable=self.__main_db_path, width=23)
         settings_fp_label.grid(row=0, column=0, padx=4, pady=5)
         settings_fp_entry.grid(row=0, column=1, padx=4, pady=5)
 
@@ -449,7 +449,7 @@ class MDG(Tk):
 
         #   Apply Main Filepath Entry Box Widget
         settings_fp_label = Label(existing_main_frame, text='Local DB Fp:')
-        settings_fp_entry = Entry(existing_main_frame, textvariable=self.__local_db_path)
+        settings_fp_entry = Entry(existing_main_frame, textvariable=self.__local_db_path, width=23)
         settings_fp_label.grid(row=1, column=0, padx=4, pady=5)
         settings_fp_entry.grid(row=1, column=1, padx=4, pady=5)
 
@@ -544,8 +544,11 @@ class MDG(Tk):
                 self.__pointer = DataConfig(file_dir=self.__local_dir, file_name_prefix='Script_Pointer',
                                             file_ext='ptr', encrypt=True)
 
-            self.__pointer.setcrypt(key='Local_DB_Path', val=os.path.join(self.__local_db_path.get(),
-                                                                          'Local_Settings.db'), private=True)
+            if os.path.isfile(self.__local_db_path.get()):
+                self.__pointer.setcrypt(key='Local_DB_Path', val=self.__local_db_path.get(), private=True)
+            else:
+                self.__pointer.setcrypt(key='Local_DB_Path', val=os.path.join(self.__local_db_path.get(),
+                                                                             'Local_Settings.db'), private=True)
 
             if os.path.isfile(self.__main_db_path.get()):
                 self.__pointer.setcrypt(key='Main_DB_Path', val=self.__main_db_path.get(), private=True)
