@@ -332,12 +332,12 @@ class SQLEngineClass(BaseSQLEngineClass, PickleMixIn):
                 keep_engine_alive = True
 
             if new_engine:
-                self.__sql_upload(engine, spid, keep_engine_alive, dataframe, table_name, table_schema, if_exists,
-                                  index, index_label, queue_cursor)
+                return self.__sql_upload(engine, spid, keep_engine_alive, dataframe, table_name, table_schema,
+                                         if_exists, index, index_label, queue_cursor)
             else:
                 with self.__engine_lock:
-                    self.__sql_upload(engine, spid, keep_engine_alive, dataframe, table_name, table_schema, if_exists,
-                                      index, index_label, queue_cursor)
+                    return self.__sql_upload(engine, spid, keep_engine_alive, dataframe, table_name, table_schema,
+                                             if_exists, index, index_label, queue_cursor)
 
     def __sql_upload(self, engine, spid, keep_engine_alive, dataframe, table_name, table_schema=None,
                      if_exists='append', index=True, index_label='ID', queue_cursor=False):
@@ -384,10 +384,10 @@ class SQLEngineClass(BaseSQLEngineClass, PickleMixIn):
             keep_engine_alive = True
 
         if new_engine:
-            self.__sql_tables(engine, spid, keep_engine_alive, queue_cursor)
+            return self.__sql_tables(engine, spid, keep_engine_alive, queue_cursor)
         else:
             with self.__engine_lock:
-                self.__sql_tables(engine, spid, keep_engine_alive, queue_cursor)
+                return self.__sql_tables(engine, spid, keep_engine_alive, queue_cursor)
 
     def __sql_tables(self, engine, spid, keep_engine_alive, queue_cursor=False):
         from ..sql.cursor import SQLCursor
